/*
 * See Licensing and Copyright notice in naev.h
 */
#pragma once

#include "nlua.h"

/*
 * Library loading
 */
int nlua_loadGUI( nlua_env *env );
